@@ -1,8 +1,9 @@
 import re
 
-generic_key_reg = re.compile('^[0-9a-zA-Z-_+. /]+$')
+meta_name_reg = re.compile('^[0-9a-zA-Z-_+ ]+$')
 meta_value_reg = re.compile('^[0-9a-zA-Z-_+., /]+$')
 tag_reg = re.compile('^[0-9a-zA-Z-_+. /]+$')
+label_name_reg = re.compile('^[0-9a-zA-Z-_+. ]+$')
 label_value_reg = re.compile('^[0-9a-zA-Z-_+., /]+$')
 
 
@@ -10,8 +11,8 @@ def validate_file_meta(meta):
     if meta is None:
         return True
     for k,v in meta.items():
-        if not generic_key_reg.match(k):
-            raise ValueError(f'Invalid metadata key {k}! Expected pattern: {generic_key_reg.pattern}')
+        if not meta_name_reg.match(k):
+            raise ValueError(f'Invalid metadata key {k}! Expected pattern: {meta_name_reg.pattern}')
         if not meta_value_reg.match(str(v)):
             raise ValueError(f'Invalid metadata value {v}! Expected pattern: {meta_value_reg.pattern}')
     return True
@@ -31,8 +32,8 @@ def validate_file_labels(labels):
     for l in labels:
         n = l.get('name')
         v = str(l.get('value'))
-        if not generic_key_reg.match(n):
-            raise ValueError(f'Invalid label name {n}! Expected pattern: {generic_key_reg.pattern}')
+        if not label_name_reg.match(n):
+            raise ValueError(f'Invalid label name {n}! Expected pattern: {label_name_reg.pattern}')
         if not label_value_reg.match(v):
             raise ValueError(f'Invalid label value {v}! Expected pattern: {meta_value_reg.pattern}')
     return True
\ No newline at end of file
